@@ -209,6 +209,7 @@ class SEAMMDatastore:
         submitted=None,
         started=None,
         finished=None,
+        parameters=None,
         status="submitted",
     ):
 
@@ -218,6 +219,9 @@ class SEAMMDatastore:
             Job.create should be used instead."
         )
 
+        if parameters is None:
+            parameters = {}
+
         with session_scope(self.Session) as session:
 
             job = self.Job.create(
@@ -230,6 +234,7 @@ class SEAMMDatastore:
                 submitted,
                 started,
                 finished,
+                parameters,
                 status,
             )
 
